package net.knarcraft.minecraftserverlauncher.server.servertypes;

/**
 * Contains the bare minimum to be a functional server type.
 *
 * @author      Kristian Knarvik <kristian.knarvik@knett.no>
 * @version     1.0.0
 * @since       1.0.0
 */
public abstract class AbstractServerType implements ServerType {
	private final String typeName;
	private final String[] versions;
	final String downloadURL;

	/**
	 * Instantiates a new server type
	 * @param typeName <p>The typeName of the server type</p>
	 * @param versions <p>A list of one or more server versions for the type</p>
	 * @param downloadURL <p>The URL used for downloading .jar files</p>
	 */
	AbstractServerType(String typeName, String[] versions, String downloadURL) {
		this.typeName = typeName;
		this.versions = versions;
		this.downloadURL = downloadURL;
	}

	/**
	 * Gets the name of the server type
	 * @return <p>Server type typeName</p>
	 */
	public String getName() {
		return this.typeName;
	}

	/**
	 * Gets a list of versions available for the server type
	 * @return <p>A list of server versions</p>
	 */
	public String[] getVersions() {
		return this.versions;
	}

	/**
	 * Gets the url used for downloading JAR files
	 * @return <p>A download URL</p>
	 */
	public String getDownloadURL() {
		return this.downloadURL;
	}

}